#ifndef SCREEM_TODO_H
#define SCREEM_TODO_H

typedef struct TodoItem {
        gchar *task;
        gchar *assigned;
        gchar *priority;
        gchar *linked_to;
        gchar *description;
} TodoItem;

TodoItem* screem_todo_item_new( void );
void screem_todo_item_destroy( TodoItem *item );
void todo_view( void );

#endif
